[![](https://img.shields.io/travis/CiscoUcs/ucsmsdk.svg)](https://travis-ci.org/CiscoUcs/ucsmsdk)
[![](https://ucspython.herokuapp.com/badge.svg)](https://ucspython.herokuapp.com)
[![](https://img.shields.io/pypi/v/ucsmsdk.svg)](https://pypi.python.org/pypi/ucsmsdk)

# Python SDK for Cisco UCS

* Apache License, Version 2.0 (the "License") 
* Documentation: https://CiscoUcs.github.io/ucsmsdk_docs/

## Installation
```
    - Install pip (skip if pip is already available):
        wget https://bootstrap.pypa.io/get-pip.py
        python get-pip.py

    git clone https://github.com/CiscoUcs/ucsmsdk.git
    cd ucsmsdk
    make install
```

## Features

* Python SDK for UCS server management and related automation
* Supports every Managed Object exposed by Ucs
* APIs for CRUD operations simplified
* Support for server side filters made simpler
* Support for eventhandlers
* Runtime memory usage is reduced
* Nosetests for unit testing
* Samples directory for more real world use cases
* Integrating the sphinx framework for documentation
* PEP8 Compliance


## Community:

* We are on Slack - slack requires registration, but the ucspython team is open invitation to
  anyone to register [here](https://ucspython.herokuapp.com) 
